diff --git a/config_update_ui/config_update_ui.drush.inc b/config_update_ui/config_update_ui.drush.inc
index 3258230..2612e08 100644
--- a/config_update_ui/config_update_ui.drush.inc
+++ b/config_update_ui/config_update_ui.drush.inc
@@ -224,9 +224,11 @@ function drush_config_update_ui_config_diff($name) {
   $active = $reverter->getFromActive('', $name);
   if ($extension && $active) {
     $diff = $differ->diff($extension, $active);
-    drush_print($formatter->format($diff));
+    $output = $formatter->format($diff);
+    return $output;
   }
   else {
     drush_print(dt('Config is missing, cannot diff'), 0, STDERR);
+    return '';
   }
 }
diff --git a/config_update_ui/config_update_ui.drush_testing.inc b/config_update_ui/config_update_ui.drush_testing.inc
new file mode 100644
index 0000000..bb369fc
--- /dev/null
+++ b/config_update_ui/config_update_ui.drush_testing.inc
@@ -0,0 +1,16 @@
+<?php
+
+/**
+ * @file
+ * Defines stubs for Drush functions and constants so tests can run.
+ *
+ * @see \Drupal\config_update_ui\Tests\ConfigUpdateTest
+ */
+
+if (!function_exists('drush_print')) {
+  function drush_print() {}
+}
+if (!function_exists('dt')) {
+  function dt($text) { return $text; }
+}
+defined('STDERR') or define('STDERR', 25);
diff --git a/config_update_ui/src/Tests/ConfigUpdateTest.php b/config_update_ui/src/Tests/ConfigUpdateTest.php
index dc2d085..e76a8df 100644
--- a/config_update_ui/src/Tests/ConfigUpdateTest.php
+++ b/config_update_ui/src/Tests/ConfigUpdateTest.php
@@ -39,6 +39,11 @@ class ConfigUpdateTest extends WebTestBase {
     // Make sure local tasks and page title are showing.
     $this->drupalPlaceBlock('local_tasks_block');
     $this->drupalPlaceBlock('page_title_block');
+
+    // Load the Drush include file so that its functions can be tested, plus
+    // the Drush testing include file.
+    module_load_include('inc', 'config_update_ui', 'config_update_ui.drush_testing');
+    module_load_include('inc', 'config_update_ui', 'config_update_ui.drush');
   }
 
   /**
@@ -53,15 +58,20 @@ class ConfigUpdateTest extends WebTestBase {
     // Verify some empty reports.
     $this->drupalGet('admin/config/development/configuration/report/type/search_page');
     $this->assertReport('Search page', [], [], [], []);
+    $this->assertDrushReports('type', 'search_page', [], [], [], []);
+
     // Module, theme, and profile reports have no 'added' section.
     $this->drupalGet('admin/config/development/configuration/report/module/search');
     $this->assertReport('Search module', [], [], [], [], ['added']);
+    $this->assertDrushReports('module', 'search', [], [], [], []);
     $this->drupalGet('admin/config/development/configuration/report/theme/classy');
     $this->assertReport('Classy theme', [], [], [], [], ['added']);
+    $this->assertDrushReports('theme', 'classy', [], [], [], []);
 
     $inactive = ['locale.settings' => 'Simple configuration'];
     $this->drupalGet('admin/config/development/configuration/report/profile');
     $this->assertReport('Testing profile', [], [], [], $inactive, ['added']);
+    $this->assertDrushReports('profile', '', [], [], [], array_keys($inactive));
 
     // Delete the user search page from the search UI and verify report for
     // both the search page config type and user module.
@@ -71,8 +81,12 @@ class ConfigUpdateTest extends WebTestBase {
     $inactive = ['search.page.user_search' => 'Users'];
     $this->drupalGet('admin/config/development/configuration/report/type/search_page');
     $this->assertReport('Search page', [], [], [], $inactive);
+    $this->assertDrushReports('type', 'search_page', [], [], [], array_keys($inactive));
+
     $this->drupalGet('admin/config/development/configuration/report/module/user');
     $this->assertReport('User module', [], [], [], $inactive, ['added', 'changed']);
+    $this->assertDrushReports('module', 'user', [], [], [],
+      ['rdf.mapping.user.user', 'search.page.user_search', 'views.view.user_admin_people', 'views.view.who_s_new', 'views.view.who_s_online' ], ['changed']);
 
     // Use the import link to get it back. Do this from the search page
     // report to make sure we are importing the right config.
@@ -82,6 +96,7 @@ class ConfigUpdateTest extends WebTestBase {
     $this->assertNoReport();
     $this->drupalGet('admin/config/development/configuration/report/type/search_page');
     $this->assertReport('Search page', [], [], [], []);
+    $this->assertDrushReports('type', 'search_page', [], [], [], []);
 
     // Edit the node search page from the search UI and verify report.
     $this->drupalGet('admin/config/search/pages');
@@ -93,6 +108,7 @@ class ConfigUpdateTest extends WebTestBase {
     $changed = ['search.page.node_search' => 'New label'];
     $this->drupalGet('admin/config/development/configuration/report/type/search_page');
     $this->assertReport('Search page', [], [], $changed, []);
+    $this->assertDrushReports('type', 'search_page', [], [], array_keys($changed), []);
 
     // Test the show differences link.
     $this->clickLink('Show differences');
@@ -101,6 +117,13 @@ class ConfigUpdateTest extends WebTestBase {
     $this->assertText('node');
     $this->assertText('new_path');
 
+    // Test the show differences Drush report.
+    $output = drush_config_update_ui_config_diff('search.page.node_search');
+    $this->assertTrue(strpos($output, 'Content') !== FALSE);
+    $this->assertTrue(strpos($output, 'New label') !== FALSE);
+    $this->assertTrue(strpos($output, 'node') !== FALSE);
+    $this->assertTrue(strpos($output, 'new_path') !== FALSE);
+
     // Test the Back link.
     $this->clickLink("Back to 'Updates report' page.");
     $this->assertNoReport();
@@ -137,6 +160,7 @@ class ConfigUpdateTest extends WebTestBase {
     $this->drupalGet('admin/config/development/configuration/report/type/search_page');
     $added = ['search.page.test' => 'test'];
     $this->assertReport('Search page', [], $added, [], []);
+    $this->assertDrushReports('type', 'search_page', [], array_keys($added), [], []);
 
     // Test the export link.
     $this->clickLink('Export');
@@ -202,7 +226,7 @@ class ConfigUpdateTest extends WebTestBase {
    * @param string[] $missing
    *   Array of items that should be listed as missing, name => label.
    * @param string[] $added
    *   Array of items that should be listed as missing, name => label.
    * @param string[] $changed
    *   Array of items that should be listed as changed, name => label.
    * @param string[] $inactive
@@ -272,6 +296,66 @@ class ConfigUpdateTest extends WebTestBase {
   }
 
   /**
+   * Asserts that the Drush reports have the correct content.
+   *
+   * @param string $type
+   *   Type of report to run (type, module, theme, etc.).
+   * @param string $name
+   *   Name of that type to run (e.g., module machine name).
+   * @param string[] $missing
+   *   Array of config items that should be listed as missing.
+   * @param string[] $added
+   *   Array of config items that should be listed as added.
+   * @param string[] $changed
+   *   Array of config items that should be listed as changed.
+   * @param string[] $inactive
+   *   Array of config items that should be listed as inactive.
+   * @param string[] $skip
+   *   Array of report sections to skip checking.
+   */
+  protected function assertDrushReports($type, $name, $missing, $added, $changed, $inactive, $skip = []) {
+    if (!in_array('missing', $skip)) {
+      $output = drush_config_update_ui_config_missing_report($type, $name);
+      $this->assertEqual(count($output), count($missing), 'Drush missing report has correct number of items');
+      if (count($missing)) {
+        foreach ($missing as $item) {
+          $this->assertTrue(in_array($item, $output), "Item $item is in the Drush missing report");
+        }
+      }
+    }
+
+    if (!in_array('added', $skip) && $type == 'type') {
+      $output = drush_config_update_ui_config_added_report($name);
+      $this->assertEqual(count($output), count($added), 'Drush added report has correct number of items');
+      if (count($added)) {
+        foreach ($added as $item) {
+          $this->assertTrue(in_array($item, $output), "Item $item is in the Drush added report");
+        }
+      }
+    }
+
+    if (!in_array('changed', $skip)) {
+      $output = drush_config_update_ui_config_different_report($type, $name);
+      $this->assertEqual(count($output), count($changed), 'Drush changed report has correct number of items');
+      if (count($changed)) {
+        foreach ($changed as $item) {
+          $this->assertTrue(in_array($item, $output), "Item $item is in the Drush changed report");
+        }
+      }
+    }
+
+    if (!in_array('inactive', $skip)) {
+      $output = drush_config_update_ui_config_inactive_report($type, $name);
+      $this->assertEqual(count($output), count($inactive), 'Drush inactive report has correct number of items');
+      if (count($inactive)) {
+        foreach ($inactive as $item) {
+          $this->assertTrue(in_array($item, $output), "Item $item is in the Drush inactive report");
+        }
+      }
+    }
+  }
+
+  /**
    * Asserts that the report is not shown.
    *
    * Assumes you are already on the report form page.
@@ -202,7 +226,7 @@ class ConfigUpdateTest extends WebTestBase {
    *   Array of items that should be listed as missing, name => label.
    * @param string[] $added
-   *   Array of items that should be listed as missing, name => label.
+   *   Array of items that should be listed as added, name => label.
    * @param string[] $changed
    *   Array of items that should be listed as changed, name => label.
